@@ -6,7 +6,7 @@
  *
  * Copyright (C) 2001-2004
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -316,6 +316,7 @@ void gcpAtom::Add(GtkWidget* w)
 							"grow_height", false,
 							"editable", false,
 							"cursor_visible", false,
+							"text_direction", GTK_TEXT_DIR_LTR,
 							NULL);
 		gnome_canvas_rich_text_ext_set_buffer(GNOME_CANVAS_RICH_TEXT_EXT(item), m_buf);
 		g_object_set_data(G_OBJECT(group), "symbol", item);
